==> whois_5.1.5.tar.xz: whois-5.1.5/new_gtlds.h <==
    ".academy",
    ".accountants",
    ".active",
    ".actor",
    ".agency",
    ".airforce",
    ".archi",
    ".army",
    ".associates",
    ".attorney",
    ".auction",
    ".audio",
    ".autos",
    ".axa",
    ".bar",
    ".bargains",
    ".bayern",
    ".beer",
    ".berlin",
    ".best",
    ".bid",
    ".bike",
    ".bio",
    ".black",
    ".blackfriday",
    ".blue",
    ".bmw",
    ".boutique",
    ".brussels",
    ".build",
    ".builders",
    ".buzz",
    ".bzh",
    ".cab",
    ".camera",
    ".camp",
    ".cancerresearch",
    ".capetown",
    ".capital",
    ".cards",
    ".care",
    ".career",
    ".careers",
    ".cash",
    ".catering",
    ".center",
    ".ceo",
    ".cheap",
    ".christmas",
    ".church",
    ".citic",
    ".city",
    ".claims",
    ".cleaning",
    ".clinic",
    ".clothing",
    ".club",
    ".codes",
    ".coffee",
    ".college",
    ".cologne",
    ".com",
    ".community",
    ".company",
    ".computer",
    ".condos",
    ".construction",
    ".consulting",
    ".contractors",
    ".cooking",
    ".cool",
    ".country",
    ".credit",
    ".creditcard",
    ".cruises",
    ".cuisinella",
    ".dance",
    ".dating",
    ".deals",
    ".degree",
    ".democrat",
    ".dental",
    ".dentist",
    ".desi",
    ".diamonds",
    ".digital",
    ".direct",
    ".directory",
    ".discount",
    ".dnp",
    ".domains",
    ".durban",
    ".education",
    ".email",
    ".engineer",
    ".engineering",
    ".enterprises",
    ".equipment",
    ".estate",
    ".eus",
    ".events",
    ".exchange",
    ".expert",
    ".exposed",
    ".fail",
    ".farm",
    ".feedback",
    ".finance",
    ".financial",
    ".fish",
    ".fishing",
    ".fitness",
    ".flights",
    ".florist",
    ".foo",
    ".foundation",
    ".frogans",
    ".fund",
    ".furniture",
    ".futbol",
    ".gal",
    ".gallery",
    ".gent",
    ".gift",
    ".gives",
    ".glass",
    ".global",
    ".globo",
    ".gmo",
    ".gop",
    ".graphics",
    ".gratis",
    ".green",
    ".gripe",
    ".guide",
    ".guitars",
    ".guru",
    ".hamburg",
    ".haus",
    ".hiphop",
    ".hiv",
    ".holdings",
    ".holiday",
    ".homes",
    ".horse",
    ".host",
    ".house",
    ".immobilien",
    ".industries",
    ".info",
    ".ink",
    ".institute",
    ".insure",
    ".international",
    ".investments",
    ".jetzt",
    ".joburg",
    ".juegos",
    ".kaufen",
    ".kim",
    ".kitchen",
    ".kiwi",
    ".koeln",
    ".krd",
    ".kred",
    ".lacaixa",
    ".land",
    ".lawyer",
    ".lease",
    ".lgbt",
    ".life",
    ".lighting",
    ".limited",
    ".limo",
    ".link",
    ".loans",
    ".london",
    ".lotto",
    ".luxe",
    ".luxury",
    ".maison",
    ".management",
    ".mango",
    ".market",
    ".marketing",
    ".media",
    ".meet",
    ".melbourne",
    ".menu",
    ".miami",
    ".mini",
    ".moda",
    ".moe",
    ".monash",
    ".mortgage",
    ".moscow",
    ".motorcycles",
    ".nagoya",
    ".navy",
    ".net",
    ".neustar",
    ".ngo",
    ".nhk",
    ".ninja",
    ".nra",
    ".nrw",
    ".nyc",
    ".okinawa",
    ".onl",
    ".org",
    ".organic",
    ".ovh",
    ".paris",
    ".partners",
    ".parts",
    ".photo",
    ".photography",
    ".photos",
    ".physio",
    ".pics",
    ".pictures",
    ".pink",
    ".place",
    ".plumbing",
    ".praxi",
    ".press",
    ".productions",
    ".properties",
    ".pub",
    ".qpon",
    ".quebec",
    ".recipes",
    ".red",
    ".rehab",
    ".reise",
    ".reisen",
    ".ren",
    ".rentals",
    ".repair",
    ".report",
    ".republican",
    ".rest",
    ".reviews",
    ".rich",
    ".rio",
    ".rocks",
    ".rodeo",
    ".ruhr",
    ".ryukyu",
    ".saarland",
    ".scb",
    ".schmidt",
    ".schule",
    ".scot",
    ".services",
    ".sexy",
    ".shiksha",
    ".shoes",
    ".singles",
    ".social",
    ".software",
    ".sohu",
    ".solar",
    ".solutions",
    ".soy",
    ".space",
    ".spiegel",
    ".supplies",
    ".supply",
    ".support",
    ".surf",
    ".surgery",
    ".suzuki",
    ".systems",
    ".tattoo",
    ".tax",
    ".technology",
    ".tienda",
    ".tips",
    ".tirol",
    ".today",
    ".tokyo",
    ".tools",
    ".town",
    ".toys",
    ".trade",
    ".training",
    ".university",
    ".uno",
    ".vacations",
    ".vegas",
    ".ventures",
    ".versicherung",
    ".vet",
    ".viajes",
    ".villas",
    ".vision",
    ".vlaanderen",
    ".vodka",
    ".vote",
    ".voting",
    ".voto",
    ".voyage",
    ".wang",
    ".watch",
    ".webcam",
    ".website",
    ".wed",
    ".whoswho",
    ".wien",
    ".wiki",
    ".works",
    ".wtc",
    ".wtf",
    ".xn--3bst00m",
    ".xn--3ds443g",
    ".xn--4gbrim",
    ".xn--55qw42g",
    ".xn--55qx5d",
    ".xn--6frz82g",
    ".xn--6qq986b3xl",
    ".xn--80adxhks",
    ".xn--80asehdb",
    ".xn--80aswg",
    ".xn--c1avg",
    ".xn--cg4bki",
    ".xn--czr694b",
    ".xn--czru2d",
    ".xn--d1acj3b",
    ".xn--fiq228c5hs",
    ".xn--fiq64b",
    ".xn--i1b6b1a6a2e",
    ".xn--io0a7i",
    ".xn--kput3i",
    ".xn--mgbab2bd",
    ".xn--ngbc5azd",
    ".xn--nqv7f",
    ".xn--nqv7fs00ema",
    ".xn--q9jyb4c",
    ".xn--rhqv96g",
    ".xn--ses554g",
    ".xn--unup4y",
    ".xn--zfr164b",
    ".xyz",
    ".yachts",
    ".yandex",
    ".yokohama",
    ".zone",

==> whois_5.2.0.tar.xz: whois-5.2.0/new_gtlds.h <==
    ".academy",
    ".accountants",
    ".active",
    ".actor",
    ".agency",
    ".airforce",
    ".archi",
    ".army",
    ".associates",
    ".attorney",
    ".auction",
    ".audio",
    ".autos",
    ".axa",
    ".bar",
    ".bargains",
    ".bayern",
    ".beer",
    ".berlin",
    ".best",
    ".bid",
    ".bike",
    ".bio",
    ".black",
    ".blackfriday",
    ".blue",
    ".bmw",
    ".bnpparibas",
    ".boo",
    ".boutique",
    ".brussels",
    ".build",
    ".builders",
    ".business",
    ".buzz",
    ".bzh",
    ".cab",
    ".camera",
    ".camp",
    ".cancerresearch",
    ".capetown",
    ".capital",
    ".caravan",
    ".cards",
    ".care",
    ".career",
    ".careers",
    ".cash",
    ".catering",
    ".center",
    ".ceo",
    ".cern",
    ".cheap",
    ".christmas",
    ".church",
    ".citic",
    ".city",
    ".claims",
    ".cleaning",
    ".click",
    ".clinic",
    ".clothing",
    ".club",
    ".codes",
    ".coffee",
    ".college",
    ".cologne",
    ".com",
    ".community",
    ".company",
    ".computer",
    ".condos",
    ".construction",
    ".consulting",
    ".contractors",
    ".cooking",
    ".cool",
    ".country",
    ".credit",
    ".creditcard",
    ".cruises",
    ".cuisinella",
    ".cymru",
    ".dad",
    ".dance",
    ".dating",
    ".day",
    ".deals",
    ".degree",
    ".democrat",
    ".dental",
    ".dentist",
    ".desi",
    ".diamonds",
    ".diet",
    ".digital",
    ".direct",
    ".directory",
    ".discount",
    ".dnp",
    ".domains",
    ".durban",
    ".eat",
    ".education",
    ".email",
    ".engineer",
    ".engineering",
    ".enterprises",
    ".equipment",
    ".esq",
    ".estate",
    ".eus",
    ".events",
    ".exchange",
    ".expert",
    ".exposed",
    ".fail",
    ".farm",
    ".feedback",
    ".finance",
    ".financial",
    ".fish",
    ".fishing",
    ".fitness",
    ".flights",
    ".florist",
    ".foo",
    ".foundation",
    ".frl",
    ".frogans",
    ".fund",
    ".furniture",
    ".futbol",
    ".gal",
    ".gallery",
    ".gbiz",
    ".gent",
    ".gift",
    ".gifts",
    ".gives",
    ".glass",
    ".global",
    ".globo",
    ".gmail",
    ".gmo",
    ".gmx",
    ".gop",
    ".graphics",
    ".gratis",
    ".green",
    ".gripe",
    ".guide",
    ".guitars",
    ".guru",
    ".hamburg",
    ".haus",
    ".healthcare",
    ".help",
    ".here",
    ".hiphop",
    ".hiv",
    ".holdings",
    ".holiday",
    ".homes",
    ".horse",
    ".host",
    ".hosting",
    ".house",
    ".how",
    ".immo",
    ".immobilien",
    ".industries",
    ".info",
    ".ing",
    ".ink",
    ".institute",
    ".insure",
    ".international",
    ".investments",
    ".jetzt",
    ".joburg",
    ".juegos",
    ".kaufen",
    ".kim",
    ".kitchen",
    ".kiwi",
    ".koeln",
    ".krd",
    ".kred",
    ".lacaixa",
    ".land",
    ".lawyer",
    ".lease",
    ".lgbt",
    ".life",
    ".lighting",
    ".limited",
    ".limo",
    ".link",
    ".loans",
    ".london",
    ".lotto",
    ".ltda",
    ".luxe",
    ".luxury",
    ".maison",
    ".management",
    ".mango",
    ".market",
    ".marketing",
    ".media",
    ".meet",
    ".melbourne",
    ".meme",
    ".menu",
    ".miami",
    ".mini",
    ".moda",
    ".moe",
    ".monash",
    ".mortgage",
    ".moscow",
    ".motorcycles",
    ".mov",
    ".nagoya",
    ".navy",
    ".net",
    ".network",
    ".neustar",
    ".new",
    ".ngo",
    ".nhk",
    ".ninja",
    ".nra",
    ".nrw",
    ".nyc",
    ".okinawa",
    ".ong",
    ".onl",
    ".ooo",
    ".org",
    ".organic",
    ".otsuka",
    ".ovh",
    ".paris",
    ".partners",
    ".parts",
    ".pharmacy",
    ".photo",
    ".photography",
    ".photos",
    ".physio",
    ".pics",
    ".pictures",
    ".pink",
    ".pizza",
    ".place",
    ".plumbing",
    ".praxi",
    ".press",
    ".prod",
    ".productions",
    ".properties",
    ".property",
    ".pub",
    ".qpon",
    ".quebec",
    ".realtor",
    ".recipes",
    ".red",
    ".rehab",
    ".reise",
    ".reisen",
    ".ren",
    ".rentals",
    ".repair",
    ".report",
    ".republican",
    ".rest",
    ".restaurant",
    ".reviews",
    ".rich",
    ".rio",
    ".rocks",
    ".rodeo",
    ".rsvp",
    ".ruhr",
    ".ryukyu",
    ".saarland",
    ".sarl",
    ".sca",
    ".scb",
    ".schmidt",
    ".schule",
    ".scot",
    ".services",
    ".sexy",
    ".shiksha",
    ".shoes",
    ".singles",
    ".social",
    ".software",
    ".sohu",
    ".solar",
    ".solutions",
    ".soy",
    ".space",
    ".spiegel",
    ".supplies",
    ".supply",
    ".support",
    ".surf",
    ".surgery",
    ".suzuki",
    ".systems",
    ".tatar",
    ".tattoo",
    ".tax",
    ".technology",
    ".tienda",
    ".tips",
    ".tirol",
    ".today",
    ".tokyo",
    ".tools",
    ".top",
    ".town",
    ".toys",
    ".trade",
    ".training",
    ".university",
    ".uno",
    ".uol",
    ".vacations",
    ".vegas",
    ".ventures",
    ".versicherung",
    ".vet",
    ".viajes",
    ".villas",
    ".vision",
    ".vlaanderen",
    ".vodka",
    ".vote",
    ".voting",
    ".voto",
    ".voyage",
    ".wales",
    ".wang",
    ".watch",
    ".webcam",
    ".website",
    ".wed",
    ".whoswho",
    ".wien",
    ".wiki",
    ".williamhill",
    ".wme",
    ".works",
    ".wtc",
    ".wtf",
    ".xn--1qqw23a",
    ".xn--3bst00m",
    ".xn--3ds443g",
    ".xn--4gbrim",
    ".xn--55qw42g",
    ".xn--55qx5d",
    ".xn--6frz82g",
    ".xn--6qq986b3xl",
    ".xn--80adxhks",
    ".xn--80asehdb",
    ".xn--80aswg",
    ".xn--c1avg",
    ".xn--cg4bki",
    ".xn--czr694b",
    ".xn--czru2d",
    ".xn--d1acj3b",
    ".xn--fiq228c5hs",
    ".xn--fiq64b",
    ".xn--i1b6b1a6a2e",
    ".xn--io0a7i",
    ".xn--kput3i",
    ".xn--mgbab2bd",
    ".xn--ngbc5azd",
    ".xn--nqv7f",
    ".xn--nqv7fs00ema",
    ".xn--q9jyb4c",
    ".xn--rhqv96g",
    ".xn--ses554g",
    ".xn--unup4y",
    ".xn--vhquv",
    ".xn--xhq521b",
    ".xn--zfr164b",
    ".xyz",
    ".yachts",
    ".yandex",
    ".yokohama",
    ".youtube",
    ".zone",
